//---------------------------------------------------------------------------
// TestSeedPredation.cpp
//---------------------------------------------------------------------------
#include "TestSeedPredation.h"
#include "SimManager.h"
#include "GridBase.h"
#include <fstream.h>
#include <math.h>

/////////////////////////////////////////////////////////////////////////////
//  TestSeedPredation()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSeedPredation()
{
  clSimManager * p_oSimManager = new clSimManager(3, 3, "");

  TestErrorProcessing(p_oSimManager);
  TestSeedPredationNormal(p_oSimManager);
  TestSetup1(p_oSimManager);
  TestSetup2(p_oSimManager);
  TestSetup3(p_oSimManager);
  TestSetup4(p_oSimManager);
  TestDensities(p_oSimManager);
  TestSeedOfftake(p_oSimManager);

  delete p_oSimManager;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestDensities()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestDensities(clSimManager *p_oSimManager) {

  clGridBase *p_oPredatorGrid, *p_oSeedsGrid;
  float fPredNum1, //number of predators after timestep 1
        fPredNum2, //number of predators after timestep 2
        fNumSeeds = 51200000.0;

  //Read in the file with preservation of predator densities
  p_oSimManager->ReadFile(WriteXMLFile6());
  p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  //Set the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum1);
  //Reset the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum2);
  //Assert that they are at least 20% different
  CPPUNIT_ASSERT(fabs(fPredNum1 - fPredNum2)/fPredNum1 > 0.2);


  //Now repeat with no preservation of predator densities
  p_oSimManager->ReadFile(WriteXMLFile7());
  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");
  //Set the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum1);
  //Reset the seeds
  p_oSeedsGrid->SetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), fNumSeeds);
  //Run one timestep
  p_oSimManager->RunSim(1);
  //Get the number of predators
  p_oPredatorGrid->GetValueOfCell(0, 0, p_oPredatorGrid->GetFloatDataCode("num preds"), &fPredNum2);
  //Assert that they are within 1%
  CPPUNIT_ASSERT(fabs(fPredNum1 - fPredNum2)/fPredNum1 < 0.01);
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSeedOfftake()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSeedOfftake(clSimManager *p_oSimManager) {

  clGridBase *p_oSeedsGrid;
  float fNumExpectedSeeds = 32753205.9,
        fSeed1Proportion = 0.25, fSeed2Proportion = 0.75,
        fNumActualSeeds,
        fSpecies1Seeds,
        fSpecies2Seeds,
        fSpecies3Seeds;

  p_oSimManager->ReadFile(WriteXMLFile8());
  p_oSimManager->RunSim(1);

  p_oSeedsGrid = p_oSimManager->GetGridObject("Dispersed Seeds");
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_0"), &fSpecies1Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_1"), &fSpecies2Seeds);
  p_oSeedsGrid->GetValueOfCell(0, 0, p_oSeedsGrid->GetFloatDataCode("seeds_2"), &fSpecies3Seeds);

  //Make sure the total is right - only species 1 and 2
  fNumActualSeeds = fSpecies1Seeds + fSpecies2Seeds;

  CPPUNIT_ASSERT(fabs(fNumExpectedSeeds - fNumActualSeeds) < 100);

  //Make sure that the species 3 level is right
  CPPUNIT_ASSERT(fabs(100000 - fSpecies3Seeds) < 1);

  //Make sure the proportions of species 1 and species 2 are right
  CPPUNIT_ASSERT(fabs((fNumExpectedSeeds * fSeed1Proportion) - fSpecies1Seeds)/fSpecies1Seeds < 0.01);
  CPPUNIT_ASSERT(fabs((fNumExpectedSeeds * fSeed2Proportion) - fSpecies2Seeds)/fSpecies2Seeds < 0.01);

}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSetup1()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSetup1(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile2());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected = 30, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSetup2()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSetup2(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile3());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(8 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected = 0, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSetup3()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSetup3(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile4());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(2 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(4 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      fExpected = iX + iY;
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSetup4()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSetup4(clSimManager *p_oSimManager) {

  p_oSimManager->ReadFile(WriteXMLFile5());

  clGridBase *p_oPredatorGrid = p_oSimManager->GetGridObject("Seed Predators");

  //Make sure it has default resolution
  CPPUNIT_ASSERT(fabs(4 - p_oPredatorGrid->GetLengthXCells()) < 0.001);
  CPPUNIT_ASSERT(fabs(4 - p_oPredatorGrid->GetLengthYCells()) < 0.001);

  //Make sure the grid cells have the right value - should all be 30
  float fExpected = 0, fActual;
  int iNumX = p_oPredatorGrid->GetNumberXCells(),
      iNumY = p_oPredatorGrid->GetNumberYCells(),
      iNumCode = p_oPredatorGrid->GetFloatDataCode("num preds"),
      iX, iY;

  for (iX = 0; iX < iNumX; iX++) {
    for (iY = 0; iY < iNumY; iY++) {
      p_oPredatorGrid->GetValueOfCell(iX, iY, iNumCode, &fActual);
      CPPUNIT_ASSERT(fabs(fActual - fExpected) < 0.001);
    }
  }
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestErrorProcessing()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestErrorProcessing(clSimManager *p_oSimManager)
{

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile1());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile1.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile1.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile2());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile2.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile2.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile3());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile3.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile3.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile4());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile4.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile4.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile5());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile5.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile5.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile6());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile6.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile6.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile7());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile7.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile7.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile8());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile8.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile8.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile9());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile9.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile9.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile10());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile10.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile10.");
    }
    ;
  }

  try
  {
    p_oSimManager->ReadFile(WriteXMLErrorFile11());
    CppUnit::Asserter::fail("TestSeedPredation error processing didn't catch error for WriteXMLErrorFile11.");
  }
  catch (modelErr err)
  {
    if (strstr(err.cFunction, "clFuncResponseSeedPredation") == NULL)
    {
      CppUnit::Asserter::fail("TestSeedPredation error processing caught wrong error for WriteXMLErrorFile11.");
    }
    ;
  }
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  TestSeedPredationNormal()
/////////////////////////////////////////////////////////////////////////////
void clTestSeedPredation::TestSeedPredationNormal(clSimManager *p_oSimManager)
{
  p_oSimManager->ReadFile(WriteXMLFile1());
  p_oSimManager->RunSim(1);
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  int iX, iY;
  float fSeedsPerCell = 8000;//51200000.0/256.0;

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"


       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">51200000</fl>"
       << "</ma_v>";



/*       << "<ma_lengthXCells>10</ma_lengthXCells>"
       << "<ma_lengthYCells>10</ma_lengthYCells>";
       for (iX = 0; iX < 16; iX++) {
         for (iY = 0; iY < 16; iY++) {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << fSeedsPerCell << "</fl>"
           << "</ma_v>";
         }
       }
*/

/*       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++) {
         for (iY = 0; iY < 80; iY++) {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << fSeedsPerCell << "</fl>"
           << "</ma_v>";
         }
       }
*/


  oOut << "</grid>"
       << "<behaviorList>" << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>"
       << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.46875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>1</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>"
       << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile4()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++)
       {
         for (iY = 0; iY < 40; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>"
       << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>1</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile5()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>4</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++)
       {
         for (iY = 0; iY < 40; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>"
       << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>"
       << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile6()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>2</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<funcResponsePredation>"
       << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>"
       << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>"
       << "<pr_numWeeksToModel>32</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>1</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile7()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>2</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<funcResponsePredation>"
       << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>"
       << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>"
       << "<pr_numWeeksToModel>32</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLFile8()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLFile8()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  int iX, iY;
  float fTotalSeeds = 51200000.0,
        fSeed1Proportion = 0.25, fSeed2Proportion = 0.75,
        fSpecieslSeeds = fTotalSeeds * fSeed1Proportion,
        fSpecies2Seeds = fTotalSeeds * fSeed2Proportion;

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>"
       << "<paramFile fileCode=\"06010101\">"
       << "<plot>"
       << "<timesteps>1</timesteps>"
       << "<yearsPerTimestep>1</yearsPerTimestep>"
       << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>"
       << "<plot_lenY>160.0</plot_lenY>"
       << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>"
       << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "<tr_species speciesName=\"Species_2\"/>"
       << "<tr_species speciesName=\"Species_3\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_2\">10.0</tr_madVal>"
       << "<tr_madVal species=\"Species_3\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_2\">1.35</tr_mshVal>"
       << "<tr_mshVal species=\"Species_3\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_2\">39.48</tr_chVal>"
       << "<tr_chVal species=\"Species_3\">39.48</tr_chVal>"
       << "</tr_canopyHeight>" << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_2\">0.0549</tr_crtdVal>"
       << "<tr_crtdVal species=\"Species_3\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_2\">1.0</tr_creVal>"
       << "<tr_creVal species=\"Species_3\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_2\">0.8008</tr_cdtdVal>"
       << "<tr_cdtdVal species=\"Species_3\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_2\">0.389</tr_fohicVal>"
       << "<tr_fohicVal species=\"Species_3\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_2\">1.0</tr_cdeVal>"
       << "<tr_cdeVal species=\"Species_3\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_2\">0.03418</tr_sohdVal>"
       << "<tr_sohdVal species=\"Species_3\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_2\">0.0299</tr_soahVal>"
       << "<tr_soahVal species=\"Species_3\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_2\">0</tr_wsehdVal>"
       << "<tr_wsehdVal species=\"Species_3\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_2\">0</tr_wsahdVal>"
       << "<tr_wsahdVal species=\"Species_3\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_2\">0</tr_wahdVal>"
       << "<tr_wahdVal species=\"Species_3\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_1\">1</ma_floatCode>"
       << "<ma_floatCode label=\"seeds_2\">2</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>"
       << "<ma_lengthYCells>160</ma_lengthYCells>"
       << "<ma_v x=\"0\" y=\"0\">"
       << "<fl c=\"0\">" << fSpecieslSeeds << "</fl>"
       << "<fl c=\"1\">" << fSpecies2Seeds << "</fl>"
       << "<fl c=\"2\">100000</fl>"
       << "</ma_v>"
       << "</grid>"
       << "<behaviorList>"
       << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "<applyTo species=\"Species_2\" type=\"Seed\"/>"
       << "</behavior>"
       << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile1()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile1()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>"
       << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>" << "<funcResponsePredation>"
       << "<pr_predatorInitialDensity>0</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile2()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile2()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>" << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.1</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile3()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile3()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>4</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>";
       for (iX = 0; iX < 40; iX++)
       {
         for (iY = 0; iY < 40; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>" << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>" << "</behaviorList>" << "<disperse>" << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>" << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>" << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>" << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>" << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.1</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>1</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile4()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile4()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>" << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>" << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>" << "<funcResponsePredation>"
       << "<pr_predatorInitialDensity>0.1</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>0</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile5()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile5()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<behaviorList>" << "<behavior>" << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>" << "<disperse>"
       << "<di_minDbhForReproduction>" << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>"
       << "</di_minDbhForReproduction>" << "<di_nonSpatialSlopeOfLambda>"
       << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>" << "</di_nonSpatialSlopeOfLambda>"
       << "<di_nonSpatialInterceptOfLambda>" << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>"
       << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>" << "<funcResponsePredation>"
       << "<pr_predatorInitialDensity>0.1</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>0</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile6()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile6()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  int iX, iY;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"num preds\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>2</ma_lengthYCells>";
       for (iX = 0; iX < 80; iX++)
       {
         for (iY = 0; iY < 80; iY++)
         {
           oOut << "<ma_v x=\"" << iX << "\" y=\"" << iY << "\">"
           << "<fl c=\"0\">" << (float)(iX + iY) << "</fl>"
           << "</ma_v>";
         }
       }
  oOut << "</grid>"
       << "<behaviorList>" << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>" << "</behaviorList>" << "<disperse>" << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>" << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>" << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>" << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>" << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.1</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>1</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile7()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile7()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">"
       << "<ma_floatCodes>"
       << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"count\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_boolCodes>"
       << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>"
       << "</ma_boolCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<grid gridName=\"Seed Predators\">"
       << "<ma_intCodes>"
       << "<ma_intCode label=\"num preds\">0</ma_intCode>"
       << "</ma_intCodes>"
       << "<ma_lengthXCells>2</ma_lengthXCells>"
       << "<ma_lengthYCells>4</ma_lengthYCells>"
       << "</grid>"
       << "<behaviorList>" << "<behavior>"
       << "<behaviorName>non spatial disperse</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Adult\"/>" << "</behavior>" << "<behavior>"
       << "<behaviorName>functional response seed predation</behaviorName>" << "<version>1</version>"
       << "<applyTo species=\"Species_1\" type=\"Seed\"/>"
       << "</behavior>" << "</behaviorList>" << "<disperse>" << "<di_minDbhForReproduction>"
       << "<di_mdfrVal species=\"Species_1\">15.0</di_mdfrVal>" << "</di_minDbhForReproduction>"
       << "<di_nonSpatialSlopeOfLambda>" << "<di_nssolVal species=\"Species_1\">0</di_nssolVal>"
       << "</di_nonSpatialSlopeOfLambda>" << "<di_nonSpatialInterceptOfLambda>"
       << "<di_nsiolVal species=\"Species_1\">0.3</di_nsiolVal>" << "</di_nonSpatialInterceptOfLambda>"
       << "<di_seedDistributionMethod>0</di_seedDistributionMethod>"
       << "</disperse>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.1</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>7295.4</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>1</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}

//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile8()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile8()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">" << "<ma_floatCodes>" << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>" << "<ma_intCodes>" << "<ma_intCode label=\"count\">0</ma_intCode>" << "</ma_intCodes>"
       << "<ma_boolCodes>" << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>" << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>" << "<ma_lengthYCells>160</ma_lengthYCells>"
  << "<ma_v x=\"0\" y=\"0\">" << "<fl c=\"0\">51200000</fl>" << "</ma_v>"
  << "</grid>" << "<behaviorList>" << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>-32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile9()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile9()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">" << "<ma_floatCodes>" << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>" << "<ma_intCodes>" << "<ma_intCode label=\"count\">0</ma_intCode>" << "</ma_intCodes>"
       << "<ma_boolCodes>" << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>" << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>" << "<ma_lengthYCells>160</ma_lengthYCells>"
  << "<ma_v x=\"0\" y=\"0\">" << "<fl c=\"0\">51200000</fl>" << "</ma_v>"
  << "</grid>" << "<behaviorList>" << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>53</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>0.35</pr_proportionGerminating>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile10()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile10()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">" << "<ma_floatCodes>" << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>" << "<ma_intCodes>" << "<ma_intCode label=\"count\">0</ma_intCode>" << "</ma_intCodes>"
       << "<ma_boolCodes>" << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>" << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>" << "<ma_lengthYCells>160</ma_lengthYCells>"
  << "<ma_v x=\"0\" y=\"0\">" << "<fl c=\"0\">51200000</fl>" << "</ma_v>"
  << "</grid>" << "<behaviorList>" << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>-0.35</pr_proportionGerminating>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------

/////////////////////////////////////////////////////////////////////////////
//  WriteXMLErrorFile11()
/////////////////////////////////////////////////////////////////////////////
char * clTestSeedPredation::WriteXMLErrorFile11()
{
  char * cFileString = "TestFile1.xml";

  //Open file to write to
  fstream oOut;
  oOut.open(cFileString, ios::out | ios::trunc);

  oOut << "<?xml version=\"1.0\" encoding=\"UTF-8\" standalone=\"no\" ?>" << "<paramFile fileCode=\"06010101\">" << "<plot>"
       << "<timesteps>1</timesteps>" << "<yearsPerTimestep>1</yearsPerTimestep>" << "<randomSeed>1</randomSeed>"
       << "<plot_lenX>160.0</plot_lenX>" << "<plot_lenY>160.0</plot_lenY>" << "<plot_latitude>55.37</plot_latitude>"
       << "</plot>" << "<trees>"
       << "<tr_speciesList>"
       << "<tr_species speciesName=\"Species_1\"/>"
       << "</tr_speciesList>"
       << "<tr_seedDiam10Cm>0.1</tr_seedDiam10Cm>"
       << "<tr_minAdultDBH>"
       << "<tr_madVal species=\"Species_1\">10.0</tr_madVal>"
       << "</tr_minAdultDBH>"
       << "<tr_maxSeedlingHeight>"
       << "<tr_mshVal species=\"Species_1\">1.35</tr_mshVal>"
       << "</tr_maxSeedlingHeight>"
       << "</trees>"
       << "<allometry>"
       << "<tr_canopyHeight>"
       << "<tr_chVal species=\"Species_1\">39.48</tr_chVal>"
       << "</tr_canopyHeight>"
       << "<tr_canopyRadiusToDBH>"
       << "<tr_crtdVal species=\"Species_1\">0.0549</tr_crtdVal>"
       << "</tr_canopyRadiusToDBH>"
       << "<tr_canopyRadiusExponent>"
       << "<tr_creVal species=\"Species_1\">1.0</tr_creVal>"
       << "</tr_canopyRadiusExponent>"
       << "<tr_conversionDiam10ToDBH>"
       << "<tr_cdtdVal species=\"Species_1\">0.8008</tr_cdtdVal>"
       << "</tr_conversionDiam10ToDBH>"
       << "<tr_fractOfHeightInCanopy>"
       << "<tr_fohicVal species=\"Species_1\">0.389</tr_fohicVal>"
       << "</tr_fractOfHeightInCanopy>"
       << "<tr_canopyDepthExponent>"
       << "<tr_cdeVal species=\"Species_1\">1.0</tr_cdeVal>"
       << "</tr_canopyDepthExponent>"
       << "<tr_slopeOfHeight-Diam10>"
       << "<tr_sohdVal species=\"Species_1\">0.03418</tr_sohdVal>"
       << "</tr_slopeOfHeight-Diam10>"
       << "<tr_slopeOfAsymHeight>"
       << "<tr_soahVal species=\"Species_1\">0.0299</tr_soahVal>"
       << "</tr_slopeOfAsymHeight>"
       << "<tr_whatSeedlingHeightDiam>"
       << "<tr_wsehdVal species=\"Species_1\">0</tr_wsehdVal>"
       << "</tr_whatSeedlingHeightDiam>"
       << "<tr_whatSaplingHeightDiam>"
       << "<tr_wsahdVal species=\"Species_1\">0</tr_wsahdVal>"
       << "</tr_whatSaplingHeightDiam>"
       << "<tr_whatAdultHeightDiam>"
       << "<tr_wahdVal species=\"Species_1\">0</tr_wahdVal>"
       << "</tr_whatAdultHeightDiam>"
       << "</allometry>"
       << "<grid gridName=\"Dispersed Seeds\">" << "<ma_floatCodes>" << "<ma_floatCode label=\"seeds_0\">0</ma_floatCode>"
       << "</ma_floatCodes>" << "<ma_intCodes>" << "<ma_intCode label=\"count\">0</ma_intCode>" << "</ma_intCodes>"
       << "<ma_boolCodes>" << "<ma_boolCode label=\"Is Gap\">0</ma_boolCode>" << "</ma_boolCodes>"
       << "<ma_lengthXCells>160</ma_lengthXCells>" << "<ma_lengthYCells>160</ma_lengthYCells>"
  << "<ma_v x=\"0\" y=\"0\">" << "<fl c=\"0\">51200000</fl>" << "</ma_v>"
  << "</grid>" << "<behaviorList>" << "<behavior>" << "<behaviorName>functional response seed predation</behaviorName>"
       << "<version>1</version>" << "<applyTo species=\"Species_1\" type=\"Seed\"/>" << "</behavior>" << "</behaviorList>"
       << "<funcResponsePredation>" << "<pr_predatorInitialDensity>0.00046875</pr_predatorInitialDensity>"
       << "<pr_maxInstantaneousDeclineRate>-0.050622442</pr_maxInstantaneousDeclineRate>"
       << "<pr_demographicEfficiency>0.000154258</pr_demographicEfficiency>"
       << "<pr_densityDependentCoefficient>-0.000718667</pr_densityDependentCoefficient>"
       << "<pr_maxIntakeRate>1042.2</pr_maxIntakeRate>" << "<pr_foragingEfficiency>0.001389</pr_foragingEfficiency>"
       << "<pr_numWeeksSeedFall>12</pr_numWeeksSeedFall>" << "<pr_numWeeksToModel>52</pr_numWeeksToModel>"
       << "<pr_weekGerminationStarts>32</pr_weekGerminationStarts>"
       << "<pr_preservePredatorDensities>0</pr_preservePredatorDensities>"
       << "<pr_proportionGerminating>1.35</pr_proportionGerminating>"
       << "<pr_outputFilename>TestSeeds.txt</pr_outputFilename>"
       << "</funcResponsePredation>" << "</paramFile>";

  oOut.close();

  return cFileString;
}
//---------------------------------------------------------------------------


