//---------------------------------------------------------------------------
// TestWeibullSnagMort
//---------------------------------------------------------------------------
#if !defined(TestWeibullSnagMort_H)
  #define TestWeibullSnagMort_H

#include <cppunit/TestFixture.h>
#include <cppunit/TestCaller.h>
#include <cppunit/TestSuite.h>

class clSimManager;

/**
* Tests the clWeibullSnagMort class.
* @author Lora E. Murphy
*/
class clTestWeibullSnagMort: public CppUnit::TestFixture
{
  public:

  /**
  * Encapsulates all the testing functions together.
  */
  void TestWeibullSnagMort();

  /**
  * Tests the mortality classes.
  * First run: WriteXMLFile1() creates the parameter file.  The file has the
  * following characteristics:
  * <ul>
  * <li>Timestep length of 1 year.
  * <li>3 species: Species 1, Species 2, Species 3.
  * <li>Snag weibull mort behavior, applied to snags of Species 1 and Species 3.
  * <li>Tree remover, applied to snags of Species 1 and Species 3.
  * <li>Size classes are 8 and 30.
  * </ul>
  * The function does the following:
  * <ol>
  * <li>1000 snags are created of each tree species in each of the size classes.
  * <li> The model is run for 10 timesteps.  After each timestep, the remaining
  * trees of each tree type and size class are counted.
  * <li> The counts are compared to expected results, give or take 5%.
  * </ol>
  * <p>
  * Second run:
  * WriteXMLFile2() creates the parameter file.  The file has the following
  * characteristics:
  * <ul>
  * <li>Timestep length of 3 years.
  * <li>3 species: Species 1, Species 2, Species 3.
  * <li>Snag weibull mort behavior, applied to snags of Species 1 and Species 3.
  * <li>Tree remover, applied to snags of Species 1 and Species 3.
  * <li>Size classes are 12 and 30.
  * </ul>
  * The function does the following:
  * <ol>
  * <li>1000 snags are created of each tree species in each of the size classes.
  * <li> The model is run for 10 timesteps.  After each timestep, the remaining
  * trees of each tree type and size class are counted.
  * <li> The counts are compared to expected results, give or take 5% (greater
  * margins are allowed for smaller numbers).
  * </ol>
  * @param p_oSimManager Object to run the testing.
  */
  void TestNormalProcessing(clSimManager *p_oSimManager);

  /**
  * Tests exception processing.  Tests the following error conditions:
  * <ul>
  * <li>Size classes overlap
  * <li>Behavior assigned to a tree type other than snag
  * </ul>
  * @param p_oSimManager Object to run the testing.
  */
  void TestExceptionProcessing(clSimManager *p_oSimManager);

  /**
  * This tests backwards compatibility with version 1.0.  This will enter a
  * parameter file where the size class definitions are in the old style as
  * single values.  This tests to make sure that the single values are assigned
  * to all species.  This runs a test like TestNormalProcessing, if all size
  * classes were the same as species 1.  WriteXMLFile3 is used for setup.
  */
  void TestBackwardsCompatibility(clSimManager *p_oSimManager);

  protected:

  /**
  * Writes a parameter file with the specifications given for
  * TestWeibullSnagMort(), run 1.
  * @return Filename written.
  */
  char * WriteXMLFile1();

  /**
  * Writes a parameter file with the specifications given for
  * TestWeibullSnagMort, run 2.
  * @return Filename written.
  */
  char * WriteXMLFile2();

  /**
  * Writes a parameter file with the specifications given for
  * TestBackwardsCompatibility().
  * @return Filename written.
  */
  char * WriteXMLFile3();

  /**
  * Writes a file where the size classes overlap.
  * @return Filename written.
  */
  char* WriteXMLErrorFile1();

  /**
  * Writes a file where a tree type other than snag is assigned to the
  * behavior.
  * @return Filename written.
  */
  char* WriteXMLErrorFile2();


};
//---------------------------------------------------------------------------

#endif // TestWeibullSnagMort_H
